cdc_sarscov2_jn1: CDC SARS-CoV-2 variant proportions: JN.1 emergence (US,...

cdc_sarscov2_jn1R Documentation

CDC SARS-CoV-2 variant proportions: JN.1 emergence (US, 2023-2024)

Description

Real surveillance data from the CDC's national genomic surveillance program covering the emergence and dominance of the SARS-CoV-2 JN.1 lineage in the United States, October 2023 through June 2024.

Usage

cdc_sarscov2_jn1

Format

A data frame with 171 rows and 4 columns:

date

Biweek ending date (Date).

lineage

Lineage name (character): JN.1, XBB.1.5, EG.5.1, HV.1, HK.3, BA.2.86, KP.2, KP.3, JN.1.11.1, Other.

count

Approximate sequence count per biweek (integer).

proportion

CDC weighted proportion estimate (numeric).

Details

Derived from CDC's published weighted variant proportion estimates. Approximate biweekly sequence counts were reconstructed from proportions using a reference total of 8,000 sequences per period. The original proportions are retained in the proportion column.

CDC COVID Data Tracker, SARS-CoV-2 Variant Proportions. Dataset ID: jr58-6ysp. https://data.cdc.gov/Laboratory-Surveillance/SARS-CoV-2-Variant-Proportions/jr58-6ysp

Public domain (U.S. Government Work, 17 USC 105).

References

Ma KC, et al. (2024). Genomic Surveillance for SARS-CoV-2 Variants. MMWR, 73(42):941–948. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.15585/mmwr.mm7342a1")}

Examples

data(cdc_sarscov2_jn1)
vd <- lfq_data(cdc_sarscov2_jn1,
               date = date, lineage = lineage, count = count)
fit <- fit_model(vd, engine = "mlr")
growth_advantage(fit, type = "relative_Rt", generation_time = 5)

lineagefreq documentation built on April 3, 2026, 9:09 a.m.