| filter_sparse | R Documentation |
Removes time points with very low total counts and lineages observed at too few time points.
filter_sparse(x, min_total = 10L, min_timepoints = 3L)
x |
An lfq_data object. |
min_total |
Minimum total sequences per time point. Default 10. |
min_timepoints |
Minimum number of time points a lineage must appear to be retained. Default 3. |
An lfq_data object with sparse entries removed.
sim <- simulate_dynamics(n_lineages = 3,
advantages = c("A" = 1.2, "B" = 0.8), seed = 1)
filtered <- filter_sparse(sim, min_total = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.