| lfq_summary | R Documentation |
Returns a one-row-per-lineage summary with growth rates, fitted frequencies at first and last time points, and growth advantage in multiple scales.
lfq_summary(fit, generation_time = NULL)
fit |
An |
generation_time |
Generation time for Rt calculation. |
A tibble.
sim <- simulate_dynamics(n_lineages = 3,
advantages = c("A" = 1.2, "B" = 0.8), seed = 1)
fit <- fit_model(sim)
lfq_summary(fit, generation_time = 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.