| read_lineage_counts | R Documentation |
A convenience wrapper for reading surveillance count data from CSV files into lfq_data format. Expects a file with at least columns for date, lineage, and count.
read_lineage_counts(
file,
date = "date",
lineage = "lineage",
count = "count",
...
)
file |
Path to CSV file. |
date |
Name of the date column. Default |
lineage |
Name of the lineage column. Default |
count |
Name of the count column. Default |
... |
Additional arguments passed to |
An lfq_data object.
# Read the bundled example CSV
f <- system.file("extdata", "example_counts.csv",
package = "lineagefreq")
x <- read_lineage_counts(f)
x
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.